﻿unit DelphiCli.Bootstrap;

interface

procedure BootstrapCli;

implementation

uses
  System.SysUtils,
  VSoft.CommandLine.Options,
  DelphiCli.Commands,
  DelphiCli.Console,
  DelphiCli.Entities,
  DelphiCli.Options,
  DelphiCli.ResourceStrings,
  DelphiCli.Templates;

procedure BootstrapCli;
var
  LCommand: TCommandDefinition;
  LOption: IOptionDefinition;
begin

  //
  // PREFERENCES
  //

  // Preferences
  TOptionsRegistry.DescriptionTab := 30;
  TOptionsRegistry.NameValueSeparator := ':';

  //
  // GLOBAL OPTIONS
  //

  // Option: "verbose"
  LOption := TOptionsRegistry.RegisterOption<Boolean>('verbose', 'v',
    StrCmdAllOptVerboseInfo,
    procedure(const AValue: Boolean)
    begin
      TOptionsGlobal.Verbose := AValue;
    end);
  LOption.HasValue := False;

  //
  // OPERATION: Help
  //

  // Command: "help"
  LCommand := TOptionsRegistry.RegisterCommand('help', '?',
    StrCmdHelpDescription, StrCmdHelpInfo, 'help <command>');

  // Option: "command"
  LOption := LCommand.RegisterUnNamedOption<string>(
    StrCmdHelpCommandInfo, 'command',
    procedure (const AValue: string)
    begin
      if Length(AValue) > 0 then
        TOptionsForHelp.CommandName := AValue
      else
        TOptionsForHelp.CommandName := 'help';
    end);
  LOption.Required := False;

  //
  // OPERATION: New
  //

  // Command: "new"
  LCommand := TOptionsRegistry.RegisterCommand('new', 'n',
    StrCmdNewDescription, StrCmdNewInfo,
    'new -type:<type> <ProjectName>');
  LCommand.Examples.Add('new -type:vcl MyProject');
  LCommand.Examples.Add('new -type:fmx MyProject');

  // Option: "type"
  LOption := LCommand.RegisterOption<TProjectType>('type', 't',
    StrCmdNewTypeInfo,
    procedure (const AValue: TProjectType)
    begin
      TOptionsForNew.ProjectType := AValue;
    end);
  LOption.Required := True;

  // Option: "name" (un-named)
  LOption := LCommand.RegisterUnNamedOption<string>(
    StrCmdNewNameInfo, 'ProjectName',
    procedure (const AValue: string)
    begin
      TOptionsForNew.ProjectName := AValue;
    end);
  LOption.Required := True;

  // Handler
  TCommandBroker.RegisterCommand('new',
    procedure ()
    begin
      if TOptionsGlobal.Verbose then
        TConsole.Log(StrLogNewInfo, TConsoleLevel.Info);
      TTemplateManager.NewProject(GetCurrentDir,
        TOptionsForNew.ProjectType, TOptionsForNew.ProjectName);
      if TOptionsGlobal.Verbose then
        TConsole.Log(Format(StrLogNewSuccess,
          [TOptionsForNew.ProjectName]), TConsoleLevel.Success);
    end);

  //
  // OPERATION: Add
  //

  // Command
  LCommand := TOptionsRegistry.RegisterCommand('add', 'a',
    StrCmdAddDescription, StrCmdAddInfo,
    'add -module:<module> <ModuleName>');
  LCommand.Examples.Add('add -module:unit UnitName');
  LCommand.Examples.Add('new -module:form FormName');
  LCommand.Examples.Add('add -module:frame FrameName');
  LCommand.Examples.Add('add -module:dm DataModuleName');

  // Option: "type"
  LOption := LCommand.RegisterOption<TModuleType>('module', 'm',
    StrCmdAddModuleInfo,
    procedure (const AValue: TModuleType)
    begin
      TOptionsForAdd.ModuleType := AValue;
    end);
  LOption.Required := True;

  // Option: "name"
  LOption := LCommand.RegisterUnNamedOption<string>(
    StrCmdAddNameInfo, 'ModuleName',
    procedure (const AValue: string)
    begin
      TOptionsForAdd.ModuleName := AValue;
    end);
  LOption.Required := True;

  // Handler
  TCommandBroker.RegisterCommand('add',
    procedure ()
    begin
      if TOptionsGlobal.Verbose then
        TConsole.Log(StrLogAddInfo, TConsoleLevel.Info);
      TTemplateManager.NewModule(GetCurrentDir,
        TOptionsForAdd.ModuleType, TOptionsForAdd.ModuleName);
      if TOptionsGlobal.Verbose then
        TConsole.Log(Format(StrLogAddSuccess,
          [TOptionsForAdd.ModuleName]), TConsoleLevel.Success);
    end);

end;

end.
