﻿unit DelphiCli.Commands;

interface

uses
  System.Generics.Collections,
  System.SysUtils;

type

  TCommandBroker = class
  private
    class var FCommandHandlers: TDictionary<string, TProc>;
  public
    class constructor Create;
    class destructor Destroy;
    class procedure ExecuteCommand(const ACommandName: string);
    class procedure RegisterCommand(const ACommandName: string; AProc: TProc);
  end;

implementation

uses
  DelphiCli.ResourceStrings;

class constructor TCommandBroker.Create;
begin
  inherited;
  FCommandHandlers := TDictionary<string, TProc>.Create;
end;

class destructor TCommandBroker.Destroy;
begin
  inherited;
  FreeAndNil(FCommandHandlers);
end;

class procedure TCommandBroker.ExecuteCommand(const ACommandName: string);
var
  LProc: TProc;
begin
  if not FCommandHandlers.TryGetValue(ACommandName, LProc) then
    raise Exception.Create(Format(StrErrCommandUnknown, [ACommandName]));
  LProc();
end;

class procedure TCommandBroker.RegisterCommand(const ACommandName: string;
  AProc: TProc);
begin
  FCommandHandlers.Add(ACommandName, AProc);
end;

end.
