﻿program DelphiCli;

{$APPTYPE CONSOLE}
{$R *.res}
{$R *.dres}

uses
  System.SysUtils,
  VSoft.CommandLine.Options,
  DelphiCli.Bootstrap in 'DelphiCli.Bootstrap.pas',
  DelphiCli.Commands in 'DelphiCli.Commands.pas',
  DelphiCli.Console in 'DelphiCli.Console.pas',
  DelphiCli.Entities in 'DelphiCli.Entities.pas',
  DelphiCli.Options in 'DelphiCli.Options.pas',
  DelphiCli.ResourceStrings in 'DelphiCli.ResourceStrings.pas',
  DelphiCli.Templates in 'DelphiCli.Templates.pas';

var
  ParseResult: ICommandLineParseResult;

begin

  try

    // Imposta il titolo della finestra della console.
    TConsole.SetTitle('Delphi CLI');

    // Inizializziamo preferenze, comandi e opzioni della CLI.
    BootstrapCli;

    // Eseguiamo il parsing degli argomenti e otteniamo il responso.
    ParseResult := TOptionsRegistry.Parse;

    // Se sono presenti errori, usciremo con errore mostrando il dettaglio.
    if ParseResult.HasErrors then
    begin
      ExitCode := 1;
      Writeln;
      Writeln(ParseResult.ErrorText);
      Exit;
    end;

    // Se non sono presenti errori ma il comando è assente o chiede la guida,
    // richiamiamo la funzione che mostra l'utilizzo del comando specificato.
    if (ParseResult.Command = EmptyStr) or (ParseResult.Command = 'help') then
    begin
      TOptionsRegistry.PrintUsage(TOptionsForHelp.CommandName,
        procedure(const AUsage: string)
        begin
          Writeln(AUsage);
        end);
      Exit;
    end;

    // Esegue la logica corrispondente al comando selezionato.
    TCommandBroker.ExecuteCommand(ParseResult.Command);

  except

    // In caso di errore, visualizziamo il dettaglio dell'eccezione.
    on E: Exception do
    begin
      TConsole.Log(Format('%s: %s', [E.ClassName, E.Message]),
        TConsoleLevel.Error);
      ExitCode := 1;
    end;

  end;

end.
