unit WebClient.Services.App;

interface

type

  TAppService = class
  public
    class procedure Run;
  end;

implementation

uses
  System.SysUtils,
  WebClient.Resources.Strings,
  WebClient.Services.Commands,
  WebClient.Services.Messages,
  WebClient.Services.Registration,
  WebClient.Services.Tray;

class procedure TAppService.Run;
var
  Operation, Params: string;
  LTray: ITrayService;
begin
  // Inizializza il servizio di visualizzazione dell'icona nella tray.
  LTray := StartTrayService;
  LTray.ShowDefault('Attendere il termine del processo');

  // Estrae l'operazione richiesta e i parametri dagli argomenti specificati
  Operation := LowerCase(Trim(ParamStr(1)));
  Params := Trim(ParamStr(2));

  // Verifica che sia stata specificata una operazione da riga di comando
  if Length(Operation) <= 0 then
  begin
    TMessageBoxService.Info(StrParamEmpty);
    Exit;
  end;

  // REGISTER
  if Operation = '/register' then
  begin
    TRegistrationService.RegisterProtocol;
    Exit;
  end;

  // UNREGISTER
  if Operation = '/unregister' then
  begin
    TRegistrationService.UnregisterProtocol;
    Exit;
  end;

  // COMMAND
  if Operation = '/command' then
  begin
    TCommandService.Execute(Params);
    Exit;
  end;

  // Visualizza un errore per segnalare l'operazione non supportata
  TMessageBoxService.Warn(Format(StrParamError, [Operation]));
end;

end.
