unit WebClient.Services.Commands;

interface

type

  TCommandService = class
  public
    class procedure Execute(AUri: string);
  end;

implementation

uses
  System.Classes,
  System.NetEncoding,
  System.SysUtils,
  WebClient.Base.Command,
  WebClient.Base.Globals,
  WebClient.Resources.Strings,
  WebClient.Services.Messages;

class procedure TCommandService.Execute(AUri: string);
var
  CommandUri: string;
  CommandName: string;
  CommandArguments: string;
  CommandSeparatorPos: Integer;
  CommandClass: TCommandClass;
  CommandInstance: TCommand;
begin
  try
    // Verifica che l'URI contenente i parametri della chiamata sia valorizzato.
    if Length(AUri) <= 0 then
    begin
      TMessageBoxService.Warn(StrCallUriEmpty);
      Exit;
    end;

    // Verifica che la lunghezza dell'URI sia sufficiente.
    if Length(AUri) < Length(StrRegisterProtocol) then
    begin
      TMessageBoxService.Error(StrCallUriError);
      Exit;
    end;

    // Verifica che il prefisso dell'URI sia quello atteso.
    if LowerCase(Copy(AUri, 1, Length(StrRegisterProtocol))) <> StrRegisterProtocol then
    begin
      TMessageBoxService.Error(StrCallUriError);
      Exit;
    end;

    // Rimuove il prefisso dall'URI e ottiene le sue parti rilevanti.
    CommandUri := Copy(AUri, Length(StrRegisterProtocol) + 1, MaxInt);

    // Decodifica le entit presenti nell'URL.
    CommandUri :=  THTMLEncoding.URL.Decode(Trim(CommandUri));

    // Suddivide il nome della funzione richiesta dai suoi argomenti.
    CommandSeparatorPos := Pos('?', CommandUri); // new
    if CommandSeparatorPos > 0 then
    begin
      CommandName := Copy(CommandUri, 1, CommandSeparatorPos - 1);
      CommandArguments := Copy(CommandUri, CommandSeparatorPos + 1, MaxInt);
    end
    else begin
      CommandName := CommandUri;
      CommandArguments := EmptyStr;
    end;

    // Verifica che il comando specificato nella chiamata sia valido.
    if Length(CommandName) <= 0 then
    begin
      TMessageBoxService.Error(StrCommandNameError);
      Exit;
    end;

    // Ricerca la classe che  stata associata al comando da eseguire.
    CommandClass := TCommandClass(FindClass('TCommand' + CommandName));

    // Verifica che la classe esista e sia stata registrata.
    if CommandClass = nil then
    begin
      TMessageBoxService.Error(StrCommandClassError);
      Exit;
    end;

    // Inizializza una nuova istanza della classe che implementa il comando
    // da eseguire e ne avvia l'esecuzione con i relativi parametri indicati.
    CommandInstance := CommandClass.Create(CommandArguments);
    try
      CommandInstance.Execute;
    finally
      CommandInstance.Free;
    end;

  except

    // Gestisce eventuali errori durante il parsing degli argomenti
    // e l'esecuzione del comando richiesto con i parametri di input.
    on E: Exception do
    begin
      // Visualizza il messaggio di errore a video per avvisare l'utente.
      TMessageBoxService.Error(Format('%s'#13#10#13#10'%s'#13#10'[%s]',
        [StrApplicationError, E.Message, E.ClassName]));
    end;
  end;

end;

end.
