unit WebClient.Services.Tray;

interface

type

  ITrayService = interface
    ['{6A35B7C2-C5CA-4B2E-9EA8-BE71F55BCB90}']
    procedure ShowDefault(const AHint: string; const ATitle: string = '');
    procedure ShowError(const AHint: string; const ATitle: string = '');
    procedure ShowInfo(const AHint: string; const ATitle: string = '');
    procedure ShowWarning(const AHint: string; const ATitle: string = '');
  end;

  function StartTrayService: ITrayService;

implementation

uses
  System.SysUtils,
  Vcl.ExtCtrls, Vcl.Forms;

type

  TTrayService = class (TInterfacedObject, ITrayService)
  private
    FTrayIcon: TTrayIcon;
    procedure InternalShow(const AHint: string; const ATitle: string = '');
  public
    constructor Create;
    destructor Destroy; override;
    procedure ShowDefault(const AHint: string; const ATitle: string = '');
    procedure ShowError(const AHint: string; const ATitle: string = '');
    procedure ShowInfo(const AHint: string; const ATitle: string = '');
    procedure ShowWarning(const AHint: string; const ATitle: string = '');
  end;

constructor TTrayService.Create;
begin
  inherited Create;
  FTrayIcon := TTrayIcon.Create(nil);
  FTrayIcon.Icon := Application.Icon;
  FTrayIcon.Visible := True;
end;

destructor TTrayService.Destroy;
begin
  if FTrayIcon <> nil then
    FreeAndNil(FTrayIcon);
  inherited Destroy;
end;

procedure TTrayService.InternalShow(const AHint, ATitle: string);
begin
  FTrayIcon.BalloonHint := AHint;
  if Length(ATitle) > 0 then
    FTrayIcon.BalloonTitle := ATitle
  else
    FTrayIcon.BalloonTitle := Application.Title;
  FTrayIcon.ShowBalloonHint;
end;

procedure TTrayService.ShowDefault(const AHint, ATitle: string);
begin
  FTrayIcon.BalloonFlags := bfNone;
  InternalShow(AHint, ATitle);
end;

procedure TTrayService.ShowError(const AHint, ATitle: string);
begin
  FTrayIcon.BalloonFlags := bfError;
  InternalShow(AHint, ATitle);
end;

procedure TTrayService.ShowInfo(const AHint, ATitle: string);
begin
  FTrayIcon.BalloonFlags := bfInfo;
  InternalShow(AHint, ATitle);
end;

procedure TTrayService.ShowWarning(const AHint, ATitle: string);
begin
  FTrayIcon.BalloonFlags := bfWarning;
  InternalShow(AHint, ATitle);
end;

function StartTrayService: ITrayService;
begin
  Result := TTrayService.Create;
end;

end.
